@@ -142,6 +142,12 @@ class AnalysisForm(forms.Form):
             wanted_fields.extend(['DistFollPause','DistPrevPause'])
         if form['placeInDialog']:
             wanted_fields.extend(['placeInDialog'])
+        if form['measure'] == 'D':
+            if form['DispersionFromAH']:
+                wanted_fields += ['AHDispersion']
+            else:
+                wanted_fields += ['Dispersion']
+        wanted_fields += ['F1','F2']
         return wanted_fields
 
     class Meta:
