@@ -1108,9 +1108,9 @@ class WordToken(models.Model):
                             'F2(Hz)':x['F2(Hz)']}
                             for x in p.get_formants(self.getDialogPath(),beg,end,nformants,ceiling)
                                 if x['F1(Hz)'] != '--undefined--' and x['F2(Hz)'] != '--undefined--']
-            to_out = [ {'time(s)':x['time(s)'],
-                            'F1(Hz)':x['F1(Hz)'],
-                            'F2(Hz)':x['F2(Hz)']}.update({k:outline[k] for k in outline
+            to_out = [ {'time':x['time(s)'],
+                            'F1':x['F1(Hz)'],
+                            'F2':x['F2(Hz)']}.update({k:outline[k] for k in outline
                                                             if k != 'formants' and k in wanted_fields})
                             for x in outline['formants']]
         else:
@@ -1125,18 +1125,17 @@ class WordToken(models.Model):
                     outline['F2'] = 'NA'
                 else:
                     outline['F2'] = F2
-            wanted_fields += ['F1','F2']
             if form['measure'] == 'D' and 'NA' not in [outline['F1'],outline['F2']]:
                 if form['DispersionFromAH']:
                     if 'AHDispersion' not in outline:
                         center = self.Dialog.Speaker.getAHCenter()
                         outline['AHDispersion'] = math.sqrt(math.pow(outline['F1']-center[0],2)+math.pow(outline['F2']-center[1],2))
-                    wanted_fields += ['AHDispersion']
+
                 else:
                     if 'Dispersion' not in outline:
                         center = self.Dialog.Speaker.getCenter()
                         outline['Dispersion'] = math.sqrt(math.pow(outline['F1']-center[0],2)+math.pow(outline['F2']-center[1],2))
-                    wanted_fields += ['Dispersion']
+
             elif form['measure'] == 'D':
                 outline['Dispersion'] = 'NA'
         to_out = [{k:outline[k] for k in outline if k in wanted_fields}]
